const crawlerService = require('../services/crawlerService');

/**
 * 爬虫控制器
 */
class CrawlerController {
  /**
   * 获取商品信息
   * @param {Request} req - 请求对象
   * @param {Response} res - 响应对象
   * @param {NextFunction} next - 下一个中间件函数
   */
  async getProductInfo(req, res, next) {
    try {
      const { url, screenshot, allSkus } = req.query;

      // 参数验证
      if (!url) {
        return res.status(400).json({
          success: false,
          error: {
            message: '商品URL是必需的',
            statusCode: 400
          }
        });
      }

      // 调用爬虫服务
      const productInfo = await crawlerService.crawlProductInfo(
        url, 
        screenshot === 'true',
        allSkus === 'true'
      );

      res.json({
        success: true,
        data: productInfo
      });
    } catch (error) {
      next(error);
    }
  }
}

module.exports = new CrawlerController(); 